@@ -1,20 +1,20 @@
 /* blas/source_gemm_r.h
- * 
- * Copyright (C) 2001 Brian Gough
- * 
+ *
+ * Copyright (C) 2001, 2007 Brian Gough
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 {
@@ -24,6 +24,11 @@
   int TransF, TransG;
   const BASE *F, *G;
 
+  int pos=0;
+  CBLAS_ERROR_GEMM(pos,Order,TransA,TransB,M,N,K,alpha,A,lda,B,ldb,beta,C,ldc);
+  if(pos)
+    cblas_xerbla(pos,__FILE__,"");
+
   if (alpha == 0.0 && beta == 1.0)
     return;
 
