@@ -1,17 +1,17 @@
 /* blas/source_syrk_c.h
- * 
+ *
  * Copyright (C) 2001, 2007 Brian Gough
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
@@ -21,6 +21,11 @@
   INDEX i, j, k;
   int uplo, trans;
 
+  int pos=0;
+  CBLAS_ERROR_SYRK(pos,Order,Uplo,Trans,N,K,alpha,A,lda,beta,C,ldc);
+  if(pos)
+    cblas_xerbla(pos,__FILE__,"");
+
   const BASE alpha_real = CONST_REAL0(alpha);
   const BASE alpha_imag = CONST_IMAG0(alpha);
 
