@@ -1,25 +1,31 @@
 /* blas/source_trsm_c.h
- * 
- * Copyright (C) 2001 Brian Gough
- * 
+ *
+ * Copyright (C) 2001, 2007 Brian Gough
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 {
   INDEX i, j, k;
   INDEX n1, n2;
+
+  int pos=0;
+  CBLAS_ERROR_TRSM(pos,Order,Side,Uplo,TransA,Diag,M,N,alpha,A,lda,B,ldb);
+  if(pos)
+    cblas_xerbla(pos,__FILE__,"");
+
   const int nonunit = (Diag == CblasNonUnit);
   const int conj = (TransA == CblasConjTrans) ? -1 : 1;
   int side, uplo, trans;
