@@ -2215,6 +2215,167 @@ int main (void)
       }
   }
 
+  /* Test some fixed-order Gauss-Legendre rule points and weights on [-1, 1] */
+  /* This verifies the (point, weight) retrieval API behaves sanely */
+  {
+    const double eps = GSL_DBL_EPSILON;
+    gsl_integration_glfixed_table *tbl;
+    int n, i;
+    double xi, wi;
+
+    // Analytical results for points and weights on [-1, 1]
+    // Pulled from http://en.wikipedia.org/wiki/Gaussian_quadrature
+    // Sorted in increasing order of Gauss points
+    const double e1[1][2] = {
+      {0, 2 }
+    };
+    const double e2[2][2] = {
+      {-1/sqrt(3), 1},
+      { 1/sqrt(3), 1}
+    };
+    const double e3[3][2] = {
+      {-sqrt(15)/5, 5./9},
+      {          0, 8./9},
+      { sqrt(15)/5, 5./9}
+    };
+    const double e4[4][2] = {
+      {-sqrt((3+2*sqrt(6./5))/7), (18-sqrt(30))/36},
+      {-sqrt((3-2*sqrt(6./5))/7), (18+sqrt(30))/36},
+      { sqrt((3-2*sqrt(6./5))/7), (18+sqrt(30))/36},
+      { sqrt((3+2*sqrt(6./5))/7), (18-sqrt(30))/36}
+    };
+    const double e5[5][2] = {
+      {-sqrt((5+2*sqrt(10./7)))/3, (322-13*sqrt(70))/900},
+      {-sqrt((5-2*sqrt(10./7)))/3, (322+13*sqrt(70))/900},
+      {                         0, 128./225             },
+      { sqrt((5-2*sqrt(10./7)))/3, (322+13*sqrt(70))/900},
+      { sqrt((5+2*sqrt(10./7)))/3, (322-13*sqrt(70))/900}
+    };
+
+    n = 1;
+    tbl = gsl_integration_glfixed_table_alloc(n);
+    for (i = 0; i < n; ++i)
+      {
+        gsl_integration_glfixed_point(-1, 1, i, &xi, &wi, tbl);
+        gsl_test_abs(xi, e1[i][0], eps, "glfixed %d-point lookup: x(%d)", n, i);
+        gsl_test_abs(wi, e1[i][1], eps, "glfixed %d-point lookup: w(%d)", n, i);
+      }
+    gsl_integration_glfixed_table_free(tbl);
+
+    n = 2;
+    tbl = gsl_integration_glfixed_table_alloc(n);
+    for (i = 0; i < n; ++i)
+      {
+        gsl_integration_glfixed_point(-1, 1, i, &xi, &wi, tbl);
+        gsl_test_abs(xi, e2[i][0], eps, "glfixed %d-point lookup: x(%d)", n, i);
+        gsl_test_abs(wi, e2[i][1], eps, "glfixed %d-point lookup: w(%d)", n, i);
+      }
+    gsl_integration_glfixed_table_free(tbl);
+
+    n = 3;
+    tbl = gsl_integration_glfixed_table_alloc(n);
+    for (i = 0; i < n; ++i)
+      {
+        gsl_integration_glfixed_point(-1, 1, i, &xi, &wi, tbl);
+        gsl_test_abs(xi, e3[i][0], eps, "glfixed %d-point lookup: x(%d)", n, i);
+        gsl_test_abs(wi, e3[i][1], eps, "glfixed %d-point lookup: w(%d)", n, i);
+      }
+    gsl_integration_glfixed_table_free(tbl);
+
+    n = 4;
+    tbl = gsl_integration_glfixed_table_alloc(n);
+    for (i = 0; i < n; ++i)
+      {
+        gsl_integration_glfixed_point(-1, 1, i, &xi, &wi, tbl);
+        gsl_test_abs(xi, e4[i][0], eps, "glfixed %d-point lookup: x(%d)", n, i);
+        gsl_test_abs(wi, e4[i][1], eps, "glfixed %d-point lookup: w(%d)", n, i);
+      }
+    gsl_integration_glfixed_table_free(tbl);
+
+    n = 5;
+    tbl = gsl_integration_glfixed_table_alloc(n);
+    for (i = 0; i < n; ++i)
+      {
+        gsl_integration_glfixed_point(-1, 1, i, &xi, &wi, tbl);
+        gsl_test_abs(xi, e5[i][0], eps, "glfixed %d-point lookup: x(%d)", n, i);
+        gsl_test_abs(wi, e5[i][1], eps, "glfixed %d-point lookup: w(%d)", n, i);
+      }
+    gsl_integration_glfixed_table_free(tbl);
+  }
+
+  /* Test some fixed-order Gauss-Legendre rule points and weights on [-2, 3] */
+  /* This verifies the (point, weight) retrieval API is okay on non-[-1,1] */
+  {
+    gsl_integration_glfixed_table *tbl;
+    double result, x, w;
+    int i;
+
+    /* Odd n = 3, f(x) = x**5 + x**4 + x**3 + x**2 + x**1 + 1 */
+    result = 0;
+    tbl = gsl_integration_glfixed_table_alloc(3);
+    for (i = 0; i < 3; ++i)
+      {
+        gsl_integration_glfixed_point(-2, 3, i, &x, &w, tbl);
+        result += w * (1 + x*(1 + x*(1 + x*(1 + x*(1 + x)))));
+      }
+    gsl_test_rel(result, 805./4, 1e-8,
+        "glfixed %d-point xi,wi eval", 3);
+    gsl_integration_glfixed_table_free(tbl);
+
+    /* Even n = 4, f(x) = x**7 + x**6 + x**5 + x**4 + x**3 + x**2 + x**1 + 1 */
+    result = 0;
+    tbl = gsl_integration_glfixed_table_alloc(4);
+    for (i = 0; i < 4; ++i)
+      {
+        gsl_integration_glfixed_point(-2, 3, i, &x, &w, tbl);
+        result += w * (1 + x*(1 + x*(1 + x*(1 + x*(1 + x*(1 + x*(1 + x)))))));
+      }
+    gsl_test_rel(result, 73925./56, 1e-8,
+        "glfixed %d-point xi,wi eval", 4);
+    gsl_integration_glfixed_table_free(tbl);
+  }
+
+  {
+    typedef double (*fptr) ( double , void * );
+    
+    const static fptr funs[25] = { &cqf1 , &cqf2 , &cqf3 , &cqf4 , &cqf5 , &cqf6 , &cqf7 , 
+                                   &cqf8 , &cqf9 , &cqf10 , &cqf11 , &cqf12 , &cqf13 , &cqf14 , &cqf15 , &cqf16 , &cqf17 ,
+                                   &cqf18 , &cqf19 , &cqf20 , &cqf21 , &cqf22 , &cqf23 , &cqf24 , &cqf25 };
+    
+    const static double ranges[50] = { 0, 1 , 0, 1 , 0, 1 , -1, 1 , -1, 1 , 0, 1 , 0, 1 , 0, 1 , 0, 1 , 
+                                       0, 1 , 0, 1 , 0, 1 , 0, 1 , 0, 10 , 0, 10 , 0, 10 , 0, 1 , 0, M_PI ,
+                                       0, 1 , -1, 1 , 0, 1 , 0, 1 , 0, 1 , 0, 3 , 0, 5 };
+    const static double f_exact[25] = { 1.7182818284590452354 , 0.7 , 2.0/3 , 0.4794282266888016674 , 
+                                        1.5822329637296729331 , 0.4 , 2 , 0.86697298733991103757 , 
+                                        1.1547005383792515290 , 0.69314718055994530942 , 0.3798854930417224753 , 
+                                        0.77750463411224827640 , 0.49898680869304550249 , 
+                                        0.5 , 1 , 0.13263071079267703209e+08 , 0.49898680869304550249 , 
+                                        0.83867634269442961454 , -1 , 1.5643964440690497731 , 
+                                        0.16349494301863722618 , -0.63466518254339257343 , 
+                                        0.013492485649467772692 , 17.664383539246514971 , 7.5 };
+    
+    double result, abserr;
+    size_t neval;
+    int fid;
+        
+    /* Loop over the functions... */
+    for ( fid = 0 ; fid < 25 ; fid++ ) {
+      gsl_integration_cquad_workspace *ws = gsl_integration_cquad_workspace_alloc ( 200 );
+      gsl_function f = make_function(funs[fid], NULL);
+      double exact = f_exact[fid];
+
+      /* Call our quadrature routine. */
+      int status = gsl_integration_cquad (&f, ranges[2*fid] , ranges[2*fid+1] , 0.0 , 1.0e-12 , ws , &result , &abserr , &neval);
+      
+      gsl_test_rel (result, exact, 1e-12, "cquad f%d", fid);
+      gsl_test (fabs(result - exact) > 5.0 * abserr, "cquad f%d error (%g actual vs %g estimated)", fid, fabs(result-exact), abserr);
+      gsl_test_int (status, GSL_SUCCESS, "cquad return code");
+
+      gsl_integration_cquad_workspace_free(ws);
+    }
+  }        
+
+
   exit (gsl_test_summary());
 } 
 
